@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent
 version: 2.2.4.1
-id: persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
-key: persi_1DaRqvZLLmTJoyQdIUKCZL
+id: persistent-2.2.4.1-263fc3840b78e27a8a6fefdb05730e03
+key: persi_Jw4E26iwxDeCcv571A8U44
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -35,37 +35,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
-hs-libraries: HSpersistent-2.2.4.1-1DaRqvZLLmTJoyQdIUKCZL
+hs-libraries: HSpersistent-2.2.4.1-Jw4E26iwxDeCcv571A8U44
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
-    http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
+    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
+    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
+    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
+    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
+    resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
 haddock-html: /usr/share/doc/haskell-persistent/html
